'use client';

import React, { useEffect, useState } from 'react';
import ReactPaginate from 'react-paginate';
import Link from 'next/link';
import {
    Box,
    Grid,
    Heading,
    Text,
    Image,
    useColorModeValue,
    Stack,
    LinkBox,
    LinkOverlay,
    Spinner,
    Center,
} from '@chakra-ui/react';

import NextLink from 'next/link';
import { apiFetch } from '@/app/utils/api';
import { endpoints } from '@/app/utils/endpoints';

interface BlogPost {
    id: number;
    title: string;
    slug: string;
    excerpt: string;
    featured_image: string;
}

export default function BlogSection() {
    const postsPerPage = 12;
    const [currentPage, setCurrentPage] = useState(0);
    const [posts, setPosts] = useState<BlogPost[]>([]);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState<string | null>(null);

    const offset = currentPage * postsPerPage;
    const currentPosts = posts.slice(offset, offset + postsPerPage);
    const pageCount = Math.ceil(posts.length / postsPerPage);

    const handlePageClick = ({ selected }: { selected: number }) => {
        setCurrentPage(selected);
    };

    useEffect(() => {
        const fetchPosts = async () => {
            try {
                const data = await apiFetch(endpoints.blog.all);
                setPosts(data);
            } catch (err: any) {
                setError(err.message);
            } finally {
                setLoading(false);
            }
        };

        fetchPosts();
    }, []);

    const cardBg = useColorModeValue('gray.100', 'gray.700');
    const titleColor = useColorModeValue('black', 'whiteAlpha.900');
    const excerptColor = useColorModeValue('gray.700', 'gray.400');

    if (loading) {
        return (
            <Center py={20}>
                <Spinner size="xl" />
            </Center>
        );
    }

    if (error) {
        return (
            <Center py={20}>
                <Text color="red.500">Error loading posts: {error}</Text>
            </Center>
        );
    }

    return (
        <Box px={{ base: 4, md: 12 }} py={{ base: 10, md: 20 }} bg={useColorModeValue('gray.50', 'gray.800')}>
            <Heading mb={8} textAlign="center" color={useColorModeValue('gray.800', 'gray.100')}>
                Latest Blog Posts
            </Heading>

            <Grid templateColumns={{ base: '1fr', md: 'repeat(3, 1fr)' }} gap={6}>
                {currentPosts.map((post) => (
                    <LinkBox
                        key={post.id}
                        as="article"
                        bg={cardBg}
                        p={6}
                        borderRadius="lg"
                        boxShadow="md"
                        _hover={{ boxShadow: 'lg', transform: 'translateY(-4px)', transition: 'all 0.3s ease' }}
                        cursor="pointer"
                    >
                        <Image
                            src={`http://127.0.0.1:8000/images/${post.featured_image}`}

                            alt={post.title}
                            mb={4}
                            borderRadius="md"
                            width="100%"
                            height="200px"
                            objectFit="cover"
                            objectPosition="center"
                        />
                        <Stack spacing={2}>
                            <Heading fontSize="lg" color={titleColor}>
                                <Link href={`/blog/${post.slug}`} passHref>
                                    <LinkOverlay as={NextLink} href={`/blog/${post.slug}`}>
                                        {post.title}
                                    </LinkOverlay>
                                </Link>
                            </Heading>
                            <Text
                                fontSize="sm"
                                color={excerptColor}
                                textAlign="justify"
                                dangerouslySetInnerHTML={{ __html: post.excerpt }}
                            />

                        </Stack>
                    </LinkBox>
                ))}
            </Grid>

            <Box mt={10} display="flex" justifyContent="center" className="pagination-wrapper">
                <ReactPaginate
                    previousLabel={<span>← Prev</span>}
                    nextLabel={<span>Next →</span>}
                    breakLabel="..."
                    onPageChange={handlePageClick}
                    pageCount={pageCount}
                    marginPagesDisplayed={1}
                    pageRangeDisplayed={2}
                    containerClassName="pagination"
                    pageClassName="page-item"
                    activeClassName="active"
                    previousClassName="page-nav"
                    nextClassName="page-nav"
                    breakClassName="page-break"
                    disabledClassName="disabled"
                />
            </Box>
        </Box>
    );
}
